@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 # Copyright 2012-2016 Mir Calculate. http://www.calculate-linux.org
 #
@@ -14,51 +14,46 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import time, os, sys
+import time
+import os
+import sys
 import subprocess
-from OpenSSL import crypto
 import shlex
+
+from OpenSSL import crypto
 from calculate.core.client.function import create_obj
 from calculate.core.server.api_types import ArrayReturnedMessage, TableAdapter
 from calculate.core.server.cert_cmd import getHwAddr, getIpLocal
 from calculate.core.server.local_call import print_brief_group
-
 from calculate.lib.cl_lang import setLocalTranslate
 from sudsds import MethodNotFound
 
+_ = lambda x: x
 setLocalTranslate('cl_console3', sys.modules[__name__])
 
 
 def _print(*args):
     print " ".join(map(lambda x: unicode(x).encode('utf-8'), args))
 
-# get list of certificate and session id
-def get_sid (SID_FILE):
-    if not os.path.exists(SID_FILE):
-        fi = open(SID_FILE, 'w')
-        fi.write('0')
-        fi.close()
-        sid = 0
-    else:
-        fi = open(SID_FILE, 'r')
-        sid = fi.read()
-        fi.close()
-    return sid
 
-def clear ():
+# get list of certificate and session id
+
+def clear():
     """ delete caching suds file """
     try:
         import glob
+
         for filename in glob.glob("/tmp/suds/suds-*"):
-            #print "delete", filename
+            # print "delete", filename
             try:
-                os.unlink (filename)
+                os.unlink(filename)
             except OSError as e:
                 _print(e.message)
-    except:
+    except Exception:
         print _("Failed to clear the cache! ")
         return 1
-    
+
+
 def get_ip_global():
     import urllib2
 
@@ -69,22 +64,16 @@ def get_ip_global():
     f.close()
     return outerIP
 
-def get_ip_mac_type(client_type = None):
-    results = []
-    #try:
-    results.append ( getIpLocal() )
-    #except:
-        #results.append ('no_ip')
-    #try:
-    results.append ( getHwAddr())
-    #except:
-        #results.append ('no_mac')
+
+def get_ip_mac_type(client_type=None):
+    results = [getIpLocal(), getHwAddr()]
     if client_type:
-        results.append (client_type)
+        results.append(client_type)
     else:
-        results.append ('console')
+        results.append('console')
     return results
 
+
 def print_brief(view, brief_label):
     for Group in view.groups.GroupField:
         if Group.name:
@@ -93,7 +82,7 @@ def print_brief(view, brief_label):
         print_brief_group(Group.fields.Field, Group.name)
 
 
-def _return_revoked_serials(self, crlfile):
+def _return_revoked_serials(crlfile):
     try:
         serials = []
         crltext = open(crlfile, 'r').read()
@@ -106,7 +95,8 @@ def _return_revoked_serials(self, crlfile):
         call = '/usr/bin/openssl crl -text -noout -in %s' % crlfile
         call = shlex.split(call)
         serials = []
-        (res,err)=subprocess.Popen(call, stdout=subprocess.PIPE).communicate()
+        (res, err) = subprocess.Popen(call,
+                                      stdout=subprocess.PIPE).communicate()
         for line in res.split('\n'):
             if line.find('Serial Number:') == -1:
                 continue
@@ -116,23 +106,26 @@ def _return_revoked_serials(self, crlfile):
             serials.append(serial)
         return serials
 
+
 def _create_obj(client, method):
     try:
         view_params = create_obj(client, method)
     except MethodNotFound:
         if method.endswith('_view'):
             method = method[:-5]
-        _print (_('Method not found: ') + method)
+        _print(_('Method not found: ') + method)
         raise Exception(1)
     return view_params
 
-def get_view_params(client, method, step = None, expert = None, brief = None, 
-                    onlyhelp = False):
+
+def get_view_params(client, method, step=None, expert=None, brief=None,
+                    onlyhelp=False, dispatch_usenew=False):
     view_params = _create_obj(client, method)
     view_params.step = step
     view_params.expert = expert
     view_params.brief = brief
     view_params.onlyhelp = onlyhelp
+    view_params.dispatch_usenew = dispatch_usenew
     return view_params
 
 
@@ -141,7 +134,8 @@ class MessageReceiver(object):
     Объект организует цикл получения сообщений от WsdlServer и передает их на
     обработку MessageDispatcher
     """
-    class States:
+
+    class States(object):
         Messages = 0
         Progress = 1
         Finish = 2
@@ -162,10 +156,10 @@ class MessageReceiver(object):
 
     @classmethod
     def from_entire(cls, client, pid, message_dispatcher=None, display=None):
-        sid = get_sid(client.SID_FILE)
+        sid = client.get_sid()
         list_pid = client.service.list_pid(sid=sid)
         if hasattr(list_pid, 'integer'):
-            if not pid in list_pid.integer:
+            if pid not in list_pid.integer:
                 display.print_error(
                     _("The process does not exist or does not belong to "
                       "your session"))
@@ -191,6 +185,7 @@ class MessageReceiver(object):
                     self.get_messages()
                 except Exception as e:
                     import traceback
+
                     traceback.print_exc()
             elif message.type == 'error':
                 self.display.print_error(message.message)
@@ -214,7 +209,7 @@ class MessageReceiver(object):
             if self.state == self.States.Messages:
                 current_frame = self.get_client_frame()
                 while current_frame in [None, [], ""]:
-                    time.sleep(float(self.client.frame_period)/10)
+                    time.sleep(float(self.client.frame_period) / 10)
                     current_frame = self.get_client_frame()
                 for item in current_frame[0]:
                     self.message_dispatcher.dispatch_message(item)
@@ -250,6 +245,7 @@ class MessageDispatcher(object):
     В дальнейшем взаимодействует с parent через методы get_progress, get_table,
     send_message, поле State
     """
+
     def __init__(self, methods=None):
         """
         @param methods: Common
